@@ -3,7 +3,7 @@ Author       : zhangxianbing
 Date         : 2021-05-24 19:20:27
 Description  : 
 LastEditors  : zhangxianbing
-LastEditTime : 2021-05-29 09:24:31
+LastEditTime : 2021-06-05 14:10:03
 """
 import codecs
 import json
@@ -26,6 +26,8 @@ class LazyProperty:
 
 
 class LoadMixin:
+    __slots__ = ()  # mixin class doesn't have instance members
+
     @staticmethod
     def _load(type_, name, value, cls, **kwargs) -> Any:
         # * forward reference type
@@ -60,10 +62,11 @@ class LoadMixin:
         if o_type in (dict, Dict):
             if value is None:
                 return {}
-            return {
-                k: LoadMixin._load(g_type[0], f"{name}.{k}", v, cls, **kwargs)
-                for k, v in value.items()
-            }
+            r = {}
+            for k, v in value.items():
+                v = LoadMixin._load(g_type[1], f"{name}.{k}", v, cls, **kwargs)
+                r[k] = v
+            return r
 
         raise RuntimeError(f"This generics is not supported `{o_type}`")
 
@@ -72,12 +75,14 @@ class LoadMixin:
         if isinstance(d, cls):
             return d
 
-        instance = cls()
+        # generate an uninitialized instance
+        instance = cls.__new__(cls)
 
         for n, t in cls.__annotations__.items():
             arg_v = d.get(n)
             def_v = getattr(instance, n, None)
-            setattr(instance, n, LoadMixin._load(t, n, arg_v or def_v, cls, **kwargs))
+            v = LoadMixin._load(t, n, arg_v or def_v, cls, **kwargs)
+            setattr(instance, n, v)
 
         return instance
 
@@ -97,6 +102,8 @@ class LoadMixin:
 
 
 class DumpMixin:
+    __slots__ = ()
+
     @staticmethod
     def _dump(value, **kwargs):
 
